# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/beo/career/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Beo\\Career\\": "packages/beo/career/src",
            "Beo\\Career\\Seeders\\": "packages/beo/career/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Beo\Career\Providers\CareerServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Career'  => Beo\Career\Facades\Career::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Beo\\Career\\Seeders\\CareerTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Beo\Career\Providers\CareerServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Beo\Career\Providers\CareerServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Beo\Career\Providers\CareerServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/career/{modulename}

**User**

    http://path-to-route-folder/user/career/{modulename}

**Public**

    http://path-to-route-folder/careers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/career/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/career/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/career/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/career/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/career/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/career/{modulename}/{slug}
    METHOD: GET