<?php

namespace Beo\Career\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Beo\Career\Http\Resources\CareerResource;
use Beo\Career\Http\Resources\CareersCollection;
use Beo\Career\Scopes\RemarkPublicScope;
use Beo\Career\Models\Remark;

class RemarkPublicController extends BaseController
{

    /**
     * Show remark's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Remark::pushScope(new RequestScope())
            ->pushScope(new RemarkPublicScope())
            ->select('remarks.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new RemarksCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('career::remark.names'))
            ->view('career::public.remark.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show remark.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Remark::findBySlug($slug);
        $data = new RemarkResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('career::remark.name'))
            ->view('career::public.remark.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
