<?php

namespace Beo\Career\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\Career\Models\Remark;

class RemarkPolicy
{

    /**
     * Determine if the given user can view the remark.
     *
     * @param UserPolicyInterface $authUser
     * @param Remark $remark
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Remark $remark)
    {
        if ($authUser->canDo('career.remark.view') && $authUser->isAdmin()) {
            return true;
        }

        return $remark->user_id == user_id() && $remark->user_type == user_type();
    }

    /**
     * Determine if the given user can create a remark.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('career.remark.create');
    }

    /**
     * Determine if the given user can update the given remark.
     *
     * @param UserPolicyInterface $authUser
     * @param Remark $remark
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Remark $remark)
    {
        if ($authUser->canDo('career.remark.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $remark->user_id == user_id() && $remark->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given remark.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Remark $remark)
    {
        return $remark->user_id == user_id() && $remark->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given remark.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Remark $remark)
    {
        if ($authUser->canDo('career.remark.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given remark.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Remark $remark)
    {
        if ($authUser->canDo('career.remark.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
