<?php

namespace Beo\Career\Providers;

use Illuminate\Support\ServiceProvider;
use Beo\Career\Careers;

class CareerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'career');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'career');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Beo\Career\Providers\AuthServiceProvider::class);
        $this->app->register(\Beo\Career\Providers\RouteServiceProvider::class);
        // $this->app->register(\Beo\Career\Providers\EventServiceProvider::class);
        // $this->app->register(\Beo\Career\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('beo.career', function($app)
        {
            return $this->app->make(Careers::class);
        });
    }



    /**
     * Merges user's and career's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'beo.career'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/job.php', 'beo.career.job'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/profile.php', 'beo.career.profile'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/profile.php', 'beo.career.profile'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/remark.php', 'beo.career.remark'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Beo\Career\Commands\Career::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['beo.career'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('beo/career')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/career')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/career')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
